/****************************************************************************
** Meta object code from reading C++ file 'keycache.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libkleo-26.04.3/src/models/keycache.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keycache.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Kleo8KeyCacheE_t {};
} // unnamed namespace

template <> constexpr inline auto Kleo::KeyCache::qt_create_metaobjectdata<qt_meta_tag_ZN4Kleo8KeyCacheE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kleo::KeyCache",
        "keyListingDone",
        "",
        "GpgME::KeyListResult",
        "result",
        "keysMayHaveChanged",
        "groupAdded",
        "Kleo::KeyGroup",
        "group",
        "groupUpdated",
        "groupRemoved",
        "clear",
        "startKeyListing",
        "GpgME::Protocol",
        "proto",
        "reload",
        "Kleo::KeyCache::ReloadOption",
        "option",
        "cancelKeyListing"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'keyListingDone'
        QtMocHelpers::SignalData<void(const GpgME::KeyListResult &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'keysMayHaveChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'groupAdded'
        QtMocHelpers::SignalData<void(const Kleo::KeyGroup &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'groupUpdated'
        QtMocHelpers::SignalData<void(const Kleo::KeyGroup &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'groupRemoved'
        QtMocHelpers::SignalData<void(const Kleo::KeyGroup &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startKeyListing'
        QtMocHelpers::SlotData<void(GpgME::Protocol)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'startKeyListing'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'reload'
        QtMocHelpers::SlotData<void(GpgME::Protocol, Kleo::KeyCache::ReloadOption)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 16, 17 },
        }}),
        // Slot 'reload'
        QtMocHelpers::SlotData<void(GpgME::Protocol)>(15, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'reload'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'cancelKeyListing'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KeyCache, qt_meta_tag_ZN4Kleo8KeyCacheE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kleo::KeyCache::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kleo8KeyCacheE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kleo8KeyCacheE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Kleo8KeyCacheE_t>.metaTypes,
    nullptr
} };

void Kleo::KeyCache::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeyCache *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->keyListingDone((*reinterpret_cast<std::add_pointer_t<GpgME::KeyListResult>>(_a[1]))); break;
        case 1: _t->keysMayHaveChanged(); break;
        case 2: _t->groupAdded((*reinterpret_cast<std::add_pointer_t<Kleo::KeyGroup>>(_a[1]))); break;
        case 3: _t->groupUpdated((*reinterpret_cast<std::add_pointer_t<Kleo::KeyGroup>>(_a[1]))); break;
        case 4: _t->groupRemoved((*reinterpret_cast<std::add_pointer_t<Kleo::KeyGroup>>(_a[1]))); break;
        case 5: _t->clear(); break;
        case 6: _t->startKeyListing((*reinterpret_cast<std::add_pointer_t<GpgME::Protocol>>(_a[1]))); break;
        case 7: _t->startKeyListing(); break;
        case 8: _t->reload((*reinterpret_cast<std::add_pointer_t<GpgME::Protocol>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Kleo::KeyCache::ReloadOption>>(_a[2]))); break;
        case 9: _t->reload((*reinterpret_cast<std::add_pointer_t<GpgME::Protocol>>(_a[1]))); break;
        case 10: _t->reload(); break;
        case 11: _t->cancelKeyListing(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KeyCache::*)(const GpgME::KeyListResult & )>(_a, &KeyCache::keyListingDone, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyCache::*)()>(_a, &KeyCache::keysMayHaveChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyCache::*)(const Kleo::KeyGroup & )>(_a, &KeyCache::groupAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyCache::*)(const Kleo::KeyGroup & )>(_a, &KeyCache::groupUpdated, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyCache::*)(const Kleo::KeyGroup & )>(_a, &KeyCache::groupRemoved, 4))
            return;
    }
}

const QMetaObject *Kleo::KeyCache::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kleo::KeyCache::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kleo8KeyCacheE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kleo::KeyCache::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void Kleo::KeyCache::keyListingDone(const GpgME::KeyListResult & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Kleo::KeyCache::keysMayHaveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Kleo::KeyCache::groupAdded(const Kleo::KeyGroup & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Kleo::KeyCache::groupUpdated(const Kleo::KeyGroup & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Kleo::KeyCache::groupRemoved(const Kleo::KeyGroup & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
