/****************************************************************************
** Meta object code from reading C++ file 'keylistmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libkleo-26.04.3/src/models/keylistmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keylistmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Kleo20AbstractKeyListModelE_t {};
} // unnamed namespace

template <> constexpr inline auto Kleo::AbstractKeyListModel::qt_create_metaobjectdata<qt_meta_tag_ZN4Kleo20AbstractKeyListModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kleo::AbstractKeyListModel",
        "rowAboutToBeMoved",
        "",
        "QModelIndex",
        "old_parent",
        "old_row",
        "rowMoved",
        "new_parent",
        "new_row",
        "setKeys",
        "std::vector<GpgME::Key>",
        "keys",
        "std::vector<GpgME::Key::Origin>",
        "extraOrigins",
        "useKeyCache",
        "value",
        "Kleo::KeyList::Options",
        "options",
        "addKey",
        "GpgME::Key",
        "key",
        "addKeys",
        "QList<QModelIndex>",
        "removeKey",
        "setGroups",
        "std::vector<KeyGroup>",
        "groups",
        "addGroup",
        "Kleo::KeyGroup",
        "group",
        "removeGroup",
        "clear",
        "Kleo::AbstractKeyListModel::ItemTypes",
        "types"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'rowAboutToBeMoved'
        QtMocHelpers::SignalData<void(const QModelIndex &, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 5 },
        }}),
        // Signal 'rowMoved'
        QtMocHelpers::SignalData<void(const QModelIndex &, int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 7 }, { QMetaType::Int, 8 },
        }}),
        // Slot 'setKeys'
        QtMocHelpers::SlotData<void(const std::vector<GpgME::Key> &, const std::vector<GpgME::Key::Origin> &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'setKeys'
        QtMocHelpers::SlotData<void(const std::vector<GpgME::Key> &)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'useKeyCache'
        QtMocHelpers::SlotData<void(bool, Kleo::KeyList::Options)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 }, { 0x80000000 | 16, 17 },
        }}),
        // Slot 'addKey'
        QtMocHelpers::SlotData<QModelIndex(const GpgME::Key &)>(18, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'addKeys'
        QtMocHelpers::SlotData<QList<QModelIndex>(const std::vector<GpgME::Key> &)>(21, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'removeKey'
        QtMocHelpers::SlotData<void(const GpgME::Key &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'setGroups'
        QtMocHelpers::SlotData<void(const std::vector<KeyGroup> &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'addGroup'
        QtMocHelpers::SlotData<QModelIndex(const Kleo::KeyGroup &)>(27, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'removeGroup'
        QtMocHelpers::SlotData<bool(const Kleo::KeyGroup &)>(30, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'clear'
        QtMocHelpers::SlotData<void(Kleo::AbstractKeyListModel::ItemTypes)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractKeyListModel, qt_meta_tag_ZN4Kleo20AbstractKeyListModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kleo::AbstractKeyListModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kleo20AbstractKeyListModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kleo20AbstractKeyListModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Kleo20AbstractKeyListModelE_t>.metaTypes,
    nullptr
} };

void Kleo::AbstractKeyListModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractKeyListModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->rowAboutToBeMoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->rowMoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 2: _t->setKeys((*reinterpret_cast<std::add_pointer_t<std::vector<GpgME::Key>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<std::vector<GpgME::Key::Origin>>>(_a[2]))); break;
        case 3: _t->setKeys((*reinterpret_cast<std::add_pointer_t<std::vector<GpgME::Key>>>(_a[1]))); break;
        case 4: _t->useKeyCache((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Kleo::KeyList::Options>>(_a[2]))); break;
        case 5: { QModelIndex _r = _t->addKey((*reinterpret_cast<std::add_pointer_t<GpgME::Key>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 6: { QList<QModelIndex> _r = _t->addKeys((*reinterpret_cast<std::add_pointer_t<std::vector<GpgME::Key>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<QModelIndex>*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->removeKey((*reinterpret_cast<std::add_pointer_t<GpgME::Key>>(_a[1]))); break;
        case 8: _t->setGroups((*reinterpret_cast<std::add_pointer_t<std::vector<KeyGroup>>>(_a[1]))); break;
        case 9: { QModelIndex _r = _t->addGroup((*reinterpret_cast<std::add_pointer_t<Kleo::KeyGroup>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->removeGroup((*reinterpret_cast<std::add_pointer_t<Kleo::KeyGroup>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->clear((*reinterpret_cast<std::add_pointer_t<Kleo::AbstractKeyListModel::ItemTypes>>(_a[1]))); break;
        case 12: _t->clear(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractKeyListModel::*)(const QModelIndex & , int )>(_a, &AbstractKeyListModel::rowAboutToBeMoved, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractKeyListModel::*)(const QModelIndex & , int )>(_a, &AbstractKeyListModel::rowMoved, 1))
            return;
    }
}

const QMetaObject *Kleo::AbstractKeyListModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kleo::AbstractKeyListModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kleo20AbstractKeyListModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KeyListModelInterface"))
        return static_cast< KeyListModelInterface*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int Kleo::AbstractKeyListModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void Kleo::AbstractKeyListModel::rowAboutToBeMoved(const QModelIndex & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Kleo::AbstractKeyListModel::rowMoved(const QModelIndex & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
