// This file is generated by kconfig_compiler_kf6 from expirycheckerconfigbase.kcfg.
// All changes you do to this file will be lost.

#include "expirycheckerconfigbase.h"

using namespace Kleo;

ExpiryCheckerConfigBase::ExpiryCheckerConfigBase( )
  : KConfigSkeleton( QStringLiteral( "kleo-expirycheckerrc" ) )
{
  setCurrentGroup( QStringLiteral( "General" ) );

  KConfigSkeleton::ItemInt  *itemOwnKeyThresholdInDays;
  itemOwnKeyThresholdInDays = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ownKeyThresholdInDays" ), mOwnKeyThresholdInDays, 30 );
  itemOwnKeyThresholdInDays->setMinValue(-1);
  itemOwnKeyThresholdInDays->setMaxValue(999);
  addItem( itemOwnKeyThresholdInDays, QStringLiteral( "ownKeyThresholdInDays" ) );
  KConfigSkeleton::ItemInt  *itemOtherKeyThresholdInDays;
  itemOtherKeyThresholdInDays = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "otherKeyThresholdInDays" ), mOtherKeyThresholdInDays, 14 );
  itemOtherKeyThresholdInDays->setMinValue(-1);
  itemOtherKeyThresholdInDays->setMaxValue(999);
  addItem( itemOtherKeyThresholdInDays, QStringLiteral( "otherKeyThresholdInDays" ) );
  KConfigSkeleton::ItemInt  *itemRootCertificateThresholdInDays;
  itemRootCertificateThresholdInDays = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "rootCertificateThresholdInDays" ), mRootCertificateThresholdInDays, 14 );
  itemRootCertificateThresholdInDays->setMinValue(-1);
  itemRootCertificateThresholdInDays->setMaxValue(999);
  addItem( itemRootCertificateThresholdInDays, QStringLiteral( "rootCertificateThresholdInDays" ) );
  KConfigSkeleton::ItemInt  *itemIntermediateCertificateThresholdInDays;
  itemIntermediateCertificateThresholdInDays = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "intermediateCertificateThresholdInDays" ), mIntermediateCertificateThresholdInDays, 14 );
  itemIntermediateCertificateThresholdInDays->setMinValue(-1);
  itemIntermediateCertificateThresholdInDays->setMaxValue(999);
  addItem( itemIntermediateCertificateThresholdInDays, QStringLiteral( "intermediateCertificateThresholdInDays" ) );
}

int ExpiryCheckerConfigBase::defaultOwnKeyThresholdInDaysValue_helper() const
{

  return 30;
}

int ExpiryCheckerConfigBase::defaultOtherKeyThresholdInDaysValue_helper() const
{

  return 14;
}

int ExpiryCheckerConfigBase::defaultRootCertificateThresholdInDaysValue_helper() const
{

  return 14;
}

int ExpiryCheckerConfigBase::defaultIntermediateCertificateThresholdInDaysValue_helper() const
{

  return 14;
}

ExpiryCheckerConfigBase::~ExpiryCheckerConfigBase()
{
}

