/****************************************************************************
** Meta object code from reading C++ file 'keylistview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libkleo-26.04.3/src/ui/keylistview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keylistview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Kleo11KeyListViewE_t {};
} // unnamed namespace

template <> constexpr inline auto Kleo::KeyListView::qt_create_metaobjectdata<qt_meta_tag_ZN4Kleo11KeyListViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kleo::KeyListView",
        "doubleClicked",
        "",
        "Kleo::KeyListViewItem*",
        "returnPressed",
        "selectionChanged",
        "contextMenu",
        "QPoint",
        "slotAddKey",
        "GpgME::Key",
        "key",
        "slotRefreshKey",
        "slotEmitDoubleClicked",
        "QTreeWidgetItem*",
        "slotEmitReturnPressed",
        "slotEmitSelectionChanged",
        "slotEmitContextMenu",
        "pos",
        "slotUpdateTimeout"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'doubleClicked'
        QtMocHelpers::SignalData<void(Kleo::KeyListViewItem *, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'returnPressed'
        QtMocHelpers::SignalData<void(Kleo::KeyListViewItem *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void(Kleo::KeyListViewItem *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'contextMenu'
        QtMocHelpers::SignalData<void(Kleo::KeyListViewItem *, const QPoint &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 7, 2 },
        }}),
        // Slot 'slotAddKey'
        QtMocHelpers::SlotData<void(const GpgME::Key &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'slotRefreshKey'
        QtMocHelpers::SlotData<void(const GpgME::Key &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'slotEmitDoubleClicked'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *, int)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'slotEmitReturnPressed'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'slotEmitSelectionChanged'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEmitContextMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 17 },
        }}),
        // Slot 'slotUpdateTimeout'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KeyListView, qt_meta_tag_ZN4Kleo11KeyListViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kleo::KeyListView::staticMetaObject = { {
    QMetaObject::SuperData::link<TreeWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kleo11KeyListViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kleo11KeyListViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Kleo11KeyListViewE_t>.metaTypes,
    nullptr
} };

void Kleo::KeyListView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeyListView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->doubleClicked((*reinterpret_cast<std::add_pointer_t<Kleo::KeyListViewItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->returnPressed((*reinterpret_cast<std::add_pointer_t<Kleo::KeyListViewItem*>>(_a[1]))); break;
        case 2: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<Kleo::KeyListViewItem*>>(_a[1]))); break;
        case 3: _t->contextMenu((*reinterpret_cast<std::add_pointer_t<Kleo::KeyListViewItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 4: _t->slotAddKey((*reinterpret_cast<std::add_pointer_t<GpgME::Key>>(_a[1]))); break;
        case 5: _t->slotRefreshKey((*reinterpret_cast<std::add_pointer_t<GpgME::Key>>(_a[1]))); break;
        case 6: _t->slotEmitDoubleClicked((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->slotEmitReturnPressed((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1]))); break;
        case 8: _t->slotEmitSelectionChanged(); break;
        case 9: _t->slotEmitContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 10: _t->slotUpdateTimeout(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KeyListView::*)(Kleo::KeyListViewItem * , int )>(_a, &KeyListView::doubleClicked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyListView::*)(Kleo::KeyListViewItem * )>(_a, &KeyListView::returnPressed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyListView::*)(Kleo::KeyListViewItem * )>(_a, &KeyListView::selectionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyListView::*)(Kleo::KeyListViewItem * , const QPoint & )>(_a, &KeyListView::contextMenu, 3))
            return;
    }
}

const QMetaObject *Kleo::KeyListView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kleo::KeyListView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kleo11KeyListViewE_t>.strings))
        return static_cast<void*>(this);
    return TreeWidget::qt_metacast(_clname);
}

int Kleo::KeyListView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TreeWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void Kleo::KeyListView::doubleClicked(Kleo::KeyListViewItem * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Kleo::KeyListView::returnPressed(Kleo::KeyListViewItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Kleo::KeyListView::selectionChanged(Kleo::KeyListViewItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Kleo::KeyListView::contextMenu(Kleo::KeyListViewItem * _t1, const QPoint & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
QT_WARNING_POP
