// This file is generated by kconfig_compiler_kf6 from openpgpcertificatecreationconfig.kcfg.
// All changes you do to this file will be lost.

#include "openpgpcertificatecreationconfig.h"

using namespace Kleo;

OpenPGPCertificateCreationConfig::OpenPGPCertificateCreationConfig( )
  : KConfigSkeleton()
{
  setCurrentGroup( QStringLiteral( "CertificateCreationWizard" ) );

  KConfigSkeleton::ItemStringList  *itemRequiredFields;
  itemRequiredFields = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "OpenPGPAttributeOrder" ), mRequiredFields );
  addItem( itemRequiredFields, QStringLiteral( "requiredFields" ) );
  KConfigSkeleton::ItemString  *itemCnPlaceholder;
  itemCnPlaceholder = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "CN_placeholder" ), mCnPlaceholder );
  addItem( itemCnPlaceholder, QStringLiteral( "cnPlaceholder" ) );
  KConfigSkeleton::ItemBool  *itemPrefillCN;
  itemPrefillCN = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "CN_prefill" ), mPrefillCN, true );
  addItem( itemPrefillCN, QStringLiteral( "prefillCN" ) );
  KConfigSkeleton::ItemString  *itemEmailPlaceholder;
  itemEmailPlaceholder = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "EMAIL_placeholder" ), mEmailPlaceholder );
  addItem( itemEmailPlaceholder, QStringLiteral( "emailPlaceholder" ) );
  KConfigSkeleton::ItemString  *itemEmailHint;
  itemEmailHint = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "EMAIL_hint" ), mEmailHint );
  addItem( itemEmailHint, QStringLiteral( "emailHint" ) );
  KConfigSkeleton::ItemString  *itemEmailLabel;
  itemEmailLabel = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "EMAIL_label" ), mEmailLabel );
  addItem( itemEmailLabel, QStringLiteral( "emailLabel" ) );
  KConfigSkeleton::ItemBool  *itemPrefillEmail;
  itemPrefillEmail = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EMAIL_prefill" ), mPrefillEmail, true );
  addItem( itemPrefillEmail, QStringLiteral( "prefillEmail" ) );
  KConfigSkeleton::ItemString  *itemEmailRegex;
  itemEmailRegex = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "EMAIL_regex" ), mEmailRegex );
  addItem( itemEmailRegex, QStringLiteral( "emailRegex" ) );
  KConfigSkeleton::ItemString  *itemEmail;
  itemEmail = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "EMAIL" ), mEmail );
  addItem( itemEmail, QStringLiteral( "email" ) );
  KConfigSkeleton::ItemString  *itemNamePlaceholder;
  itemNamePlaceholder = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "NAME_placeholder" ), mNamePlaceholder );
  addItem( itemNamePlaceholder, QStringLiteral( "namePlaceholder" ) );
  KConfigSkeleton::ItemString  *itemNameRegex;
  itemNameRegex = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "NAME_regex" ), mNameRegex );
  addItem( itemNameRegex, QStringLiteral( "nameRegex" ) );
  KConfigSkeleton::ItemString  *itemNameHint;
  itemNameHint = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "NAME_hint" ), mNameHint );
  addItem( itemNameHint, QStringLiteral( "nameHint" ) );
  KConfigSkeleton::ItemString  *itemNameLabel;
  itemNameLabel = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "NAME_label" ), mNameLabel );
  addItem( itemNameLabel, QStringLiteral( "nameLabel" ) );
  KConfigSkeleton::ItemBool  *itemPrefillName;
  itemPrefillName = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "NAME_prefill" ), mPrefillName, true );
  addItem( itemPrefillName, QStringLiteral( "prefillName" ) );
  KConfigSkeleton::ItemString  *itemName;
  itemName = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "NAME" ), mName );
  addItem( itemName, QStringLiteral( "name" ) );
  KConfigSkeleton::ItemInt  *itemValidityPeriodInDays;
  itemValidityPeriodInDays = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ValidityPeriodInDays" ), mValidityPeriodInDays, -1 );
  addItem( itemValidityPeriodInDays, QStringLiteral( "ValidityPeriodInDays" ) );
  KConfigSkeleton::ItemInt  *itemValidityPeriodInDaysMin;
  itemValidityPeriodInDaysMin = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ValidityPeriodInDaysMin" ), mValidityPeriodInDaysMin, 1 );
  addItem( itemValidityPeriodInDaysMin, QStringLiteral( "ValidityPeriodInDaysMin" ) );
  KConfigSkeleton::ItemInt  *itemValidityPeriodInDaysMax;
  itemValidityPeriodInDaysMax = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ValidityPeriodInDaysMax" ), mValidityPeriodInDaysMax, -1 );
  addItem( itemValidityPeriodInDaysMax, QStringLiteral( "ValidityPeriodInDaysMax" ) );
  KConfigSkeleton::ItemBool  *itemHideAdvanced;
  itemHideAdvanced = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HideAdvanced" ), mHideAdvanced, false );
  addItem( itemHideAdvanced, QStringLiteral( "HideAdvanced" ) );
  KConfigSkeleton::ItemBool  *itemWithPassphrase;
  itemWithPassphrase = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "WithPassphrase" ), mWithPassphrase, false );
  addItem( itemWithPassphrase, QStringLiteral( "WithPassphrase" ) );
}

bool OpenPGPCertificateCreationConfig::defaultPrefillCNValue_helper() const
{

  return true;
}

bool OpenPGPCertificateCreationConfig::defaultPrefillEmailValue_helper() const
{

  return true;
}

bool OpenPGPCertificateCreationConfig::defaultPrefillNameValue_helper() const
{

  return true;
}

int OpenPGPCertificateCreationConfig::defaultValidityPeriodInDaysValue_helper() const
{

  return -1;
}

int OpenPGPCertificateCreationConfig::defaultValidityPeriodInDaysMinValue_helper() const
{

  return 1;
}

int OpenPGPCertificateCreationConfig::defaultValidityPeriodInDaysMaxValue_helper() const
{

  return -1;
}

bool OpenPGPCertificateCreationConfig::defaultHideAdvancedValue_helper() const
{

  return false;
}

bool OpenPGPCertificateCreationConfig::defaultWithPassphraseValue_helper() const
{

  return false;
}

OpenPGPCertificateCreationConfig::~OpenPGPCertificateCreationConfig()
{
}

