/****************************************************************************
** Meta object code from reading C++ file 'expirychecker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libkleo-26.04.3/src/kleo/expirychecker.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'expirychecker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Kleo13ExpiryCheckerE_t {};
} // unnamed namespace

template <> constexpr inline auto Kleo::ExpiryChecker::qt_create_metaobjectdata<qt_meta_tag_ZN4Kleo13ExpiryCheckerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kleo::ExpiryChecker",
        "expiryMessage",
        "",
        "GpgME::Key",
        "key",
        "msg",
        "Kleo::ExpiryChecker::ExpiryInformation",
        "info",
        "isNewMessage",
        "CheckFlag",
        "EncryptionKey",
        "SigningKey",
        "CertificationKey",
        "OwnKey",
        "OwnEncryptionKey",
        "OwnSigningKey",
        "CheckChain",
        "UsageMask",
        "CheckFlags",
        "ExpirationStatus",
        "NotNearExpiry",
        "ExpiresSoon",
        "Expired",
        "NoSuitableSubkey",
        "InvalidKey",
        "InvalidCheckFlags",
        "ExpiryInformation",
        "OwnKeyExpired",
        "OwnKeyNearExpiry",
        "OtherKeyExpired",
        "OtherKeyNearExpiry"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'expiryMessage'
        QtMocHelpers::SignalData<void(const GpgME::Key &, QString, Kleo::ExpiryChecker::ExpiryInformation, bool) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { QMetaType::Bool, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'CheckFlag'
        QtMocHelpers::EnumData<enum CheckFlag>(9, 9, QMC::EnumFlags{}).add({
            {   10, CheckFlag::EncryptionKey },
            {   11, CheckFlag::SigningKey },
            {   12, CheckFlag::CertificationKey },
            {   13, CheckFlag::OwnKey },
            {   14, CheckFlag::OwnEncryptionKey },
            {   15, CheckFlag::OwnSigningKey },
            {   16, CheckFlag::CheckChain },
            {   17, CheckFlag::UsageMask },
        }),
        // flag 'CheckFlags'
        QtMocHelpers::EnumData<CheckFlags>(18, 9, QMC::EnumIsFlag).add({
            {   10, CheckFlag::EncryptionKey },
            {   11, CheckFlag::SigningKey },
            {   12, CheckFlag::CertificationKey },
            {   13, CheckFlag::OwnKey },
            {   14, CheckFlag::OwnEncryptionKey },
            {   15, CheckFlag::OwnSigningKey },
            {   16, CheckFlag::CheckChain },
            {   17, CheckFlag::UsageMask },
        }),
        // enum 'ExpirationStatus'
        QtMocHelpers::EnumData<enum ExpirationStatus>(19, 19, QMC::EnumFlags{}).add({
            {   20, ExpirationStatus::NotNearExpiry },
            {   21, ExpirationStatus::ExpiresSoon },
            {   22, ExpirationStatus::Expired },
            {   23, ExpirationStatus::NoSuitableSubkey },
            {   24, ExpirationStatus::InvalidKey },
            {   25, ExpirationStatus::InvalidCheckFlags },
        }),
        // enum 'ExpiryInformation'
        QtMocHelpers::EnumData<enum ExpiryInformation>(26, 26, QMC::EnumFlags{}).add({
            {   27, ExpiryInformation::OwnKeyExpired },
            {   28, ExpiryInformation::OwnKeyNearExpiry },
            {   29, ExpiryInformation::OtherKeyExpired },
            {   30, ExpiryInformation::OtherKeyNearExpiry },
        }),
    };
    return QtMocHelpers::metaObjectData<ExpiryChecker, qt_meta_tag_ZN4Kleo13ExpiryCheckerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kleo::ExpiryChecker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kleo13ExpiryCheckerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kleo13ExpiryCheckerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Kleo13ExpiryCheckerE_t>.metaTypes,
    nullptr
} };

void Kleo::ExpiryChecker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ExpiryChecker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->expiryMessage((*reinterpret_cast<std::add_pointer_t<GpgME::Key>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Kleo::ExpiryChecker::ExpiryInformation>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Kleo::ExpiryChecker::ExpiryInformation >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ExpiryChecker::*)(const GpgME::Key & , QString , Kleo::ExpiryChecker::ExpiryInformation , bool ) const>(_a, &ExpiryChecker::expiryMessage, 0))
            return;
    }
}

const QMetaObject *Kleo::ExpiryChecker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kleo::ExpiryChecker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kleo13ExpiryCheckerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kleo::ExpiryChecker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void Kleo::ExpiryChecker::expiryMessage(const GpgME::Key & _t1, QString _t2, Kleo::ExpiryChecker::ExpiryInformation _t3, bool _t4)const
{
    QMetaObject::activate<void>(const_cast< Kleo::ExpiryChecker *>(this), &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}
QT_WARNING_POP
