// This file is generated by kconfig_compiler_kf6 from classifyconfig.kcfg.
// All changes you do to this file will be lost.

#include "classifyconfig.h"

using namespace Kleo;

ClassifyConfig::ClassifyConfig( )
  : KConfigSkeleton( QStringLiteral( "kleo-classifyrc" ) )
{
  setCurrentGroup( QStringLiteral( "General" ) );

  KConfigSkeleton::ItemBool  *itemP7mWithoutExtensionAreEmail;
  itemP7mWithoutExtensionAreEmail = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "p7mWithoutExtensionAreEmail" ), mP7mWithoutExtensionAreEmail, true );
  addItem( itemP7mWithoutExtensionAreEmail, QStringLiteral( "p7mWithoutExtensionAreEmail" ) );
}

bool ClassifyConfig::defaultP7mWithoutExtensionAreEmailValue_helper() const
{

  return true;
}

ClassifyConfig::~ClassifyConfig()
{
}

